#!/bin/sh

# Licensed Materials - Property of IBM
# 5648-AE1  
# (c) Copyright IBM Corp. 2014.

NEWVERSION='110'
NEWVERSIONWITHDOT='1.1.0'
updateWave=false ; updateCommon=false ;updateBackground=false;updateDBRestorer=false;updateEncKey=false;updateCLI=false
updateWebScript=false;updateWaveJnlp=false;updateBackgroundServices=false;updateTestJnlp=false;updatePassResetter=false
updateTestAPI=false;updateIndex=false;updateStyle=false;updateExecNotification=false;updateWaveSrvIP=false;updateVersionScript=false
updateServerConf=false;updateHttpd=false;updateHttpdRh5=false;updateHttpdRh6=false;updateLoadClc=false;updateLogRotate=false;updateMyCnf=false
updateMyCnfRh=false;updateWaveCron=false;updateInternalExecutor=false;updateDBRestoreScript=false;updateEncryptChanger=false;updatePassResetterScript=false
updateNetworkUpdate=false;updatePackWaveCLI=false;updateCLIBat=false;updateCLIScr=false;updateSM=false;updateDataCapture=false;updateDataCaptureScript=false
update=false

tables=("AGC_Entry_Table" "BTS_Request_Statistics_Table" "BTS_Request_Table" 
"BTS_Schedule_Table" "BTS_Workunit_Table" "COR_Entry_Log_Active_Table" "COR_Entry_Table" 
"FCP_Connection_Table" "FCP_Disk_Table" "FCP_WWPN_SC_Table" "Linux_Repository_Table" 
"OS_Distribution_Table" "Site_Project_Table" "VM_Account_Table" "VM_CPC_Table" 
"VM_DASD_Group_Common_Table" "VM_DASD_Group_Specific_Table" 
"VM_DASD_Region_Common_Table" "VM_DASD_Region_Group_Relation_Table" 
"VM_DASD_Region_Specific_Table" "VM_DASD_Volume_Table" "VM_Directory_Table" 
"VM_Performance_Table" "VM_Profile_Common_Table" "VM_Profile_Specific_Table" 
"VM_Prototype_Common_Table" "VM_Prototype_Specific_Table" "VM_System_Table" 
"VM_User_Common_Table" "VM_User_Group_Table" "VM_User_Specific_Table" 
"VM_Workunit_Table" "WAVE_Attention_Required_Table" "WAVE_Custom_Attribute_Table" 
"WAVE_External_Call_Messages" "WAVE_External_Resource_Messages_Detailed_US" 
"WAVE_External_Resource_Messages_Short_US" "WAVE_LOG" "WAVE_Managed_Entity_Connection_Table" 
"WAVE_Managed_Entity_Table" "WAVE_Messages" "WAVE_Parameter_Table" "WAVE_Personalization_Table" 
"WAVE_Script_Template_Table" "WAVE_User_Group_Table" "WAVE_User_Permission_Table" 
"WAVE_User_Profile_LDAP_Group_Table" "WAVE_User_Profile_Table" 
"WAVE_User_Profile_User_Table" "WAVE_User_Script_Table" "WAVE_User_Table" 
"WAVE_VM_Update_Table" "WAVE_Virtual_Network_Segment_Relation_Table" 
"WAVE_Virtual_Network_Segment_Table" "WAVE_WRS_Table" "WAVE_Workunit_Table" 
"zVM_Device_Pool_Association_Table" "zVM_Device_Pool_Table" "zVM_Guest_LAN_Table" 
"zVM_Real_Device_Dedicate_Link_Table" "zVM_Real_Device_Table" "zVM_Unique_ID_Table" 
"zVM_VSwitch_Table" "zVM_Virtual_Network_Connection_Table" )


CURRDATE=$(date +%F)
logFile='/var/log/WAVE/updateLog-'$CURRDATE
BACKUP_DIR_NAME=backup-$CURRDATE
BACKUP_DIR="/usr/wave/$BACKUP_DIR_NAME"
BASEDIR='/usr/wave'
#Directory the script (and therefore the files to be copied) are located in
runDir="$( cd "$( dirname "$0" )" && pwd )"
IP_ADDRESS=$(ifconfig  | grep 'inet addr:'| grep -v '127.0.0.1' -m 1 | cut -d: -f2 |
awk '{ print $1}')	


#converts BTS build number to determine 
#what fix pack it correspons to
#
#Input: BTS build level (e.g. 503). 
#
#Echo Output: The fix pack number.  (e.g. An input of 503 would have an output of 3)
#	If input is unrecognized, this function will echo -1
function getFixPackNumber() {
	buildLevel=$1
	
	if (( $buildLevel > 503 ));then
		echo 4
		return
	fi
	
	case $buildLevel in
		503)
			echo 3
			;;
		*)
			echo -1
	esac
}

#Uses regex to pull versions from Jars, first argument passed to the function is the wave basedir to check for versions,
#Second argument is used to prepend "update" to the variables so we can compare the installed versions to update versions later
#Also sets jar paths, because jar versions in the name may be different
function setCurrentVersions() {
	
	waveJarLocale="$BASEDIR/GUI/appl/WAVE$NEWVERSION.jar"
	waveJar=$(ls $waveJarLocale)
	verInfo=$(java -cp $waveJar com.CSL.WAVE.versionInfo.GUIBuildStringGen -version)
	waveVer=$(echo $verInfo |grep -Eo "Version [0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,2}" |grep -Eo "[0-9]\.[0-9]\.[0-9]"|tr -d '.')
	waveBuild=$(echo $verInfo |grep -Eo "Build [0-9]{3,5}"|grep -Eo "[0-9]{3,5}")	
	
	commonJarLocale="$BASEDIR/GUI/Common/WAVECommon$NEWVERSION.jar"
	commonJar=$(ls $commonJarLocale)
	verInfo=$(java -cp $commonJar com.CSL.WAVE.versionInfo.CommonsBuildStringGen -version)
	commonVer=$(echo $verInfo |grep -Eo "Version [0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,2}" |grep -Eo "[0-9]\.[0-9]\.[0-9]"|tr -d '.')	
	commonBuild=$(echo $verInfo |grep -Eo "Build [0-9]{3,5}" |grep -Eo "[0-9]{3,5}")
	
	backgroundJarLocale="$BASEDIR/WAVEBackground/WAVEBackground$NEWVERSION.jar"
	backgroundJar=$(ls $backgroundJarLocale)
	verInfo=$(java -cp $backgroundJar com.CSL.WAVE.versionInfo.DBUpdateBuildStringGen -version)
	backgroundVer=$(echo $verInfo |grep -Eo "Version [0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,2}" |grep -Eo "[0-9]\.[0-9]\.[0-9]"|tr -d '.')
	backgroundBuild=$(echo $verInfo |grep -Eo "Build [0-9]{3,5}"| grep -Eo "[0-9]{3,5}")
	backgroundFixPack=$(getFixPackNumber $backgroundBuild)
	
	testApiJarLocale="$BASEDIR/GUI/TestAPI/TestAppl.jar"
	testApiJar=$(ls $testApiJarLocale)	
	verInfo=$(java -cp $testApiJar com.CSL.WAVE.versionInfo.TestAPIBuildStringGen -version)
	testApiVer=$(echo $verInfo |grep -Eo "Version [0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,2}" |grep -Eo "[0-9]\.[0-9]\.[0-9]"|tr -d '.')
	testApiBuild=$(echo $verInfo |grep -Eo "Build [0-9]{3,5}"| grep -Eo "[0-9]{3,5}")	

	DBRestoreJarLocale="$BASEDIR/WAVEBackground/WAVEDBRestorer$NEWVERSION.jar"
	DBRestoreJar=$(ls $DBRestoreJarLocale)
	verInfo=$(java -cp $DBRestoreJar com.CSL.WAVE.versionInfo.WAVEDBRestoreBuildStringGen -version)	
	DBRestoreVer=$(echo $verInfo |grep -Eo "Version [0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,2}" |grep -Eo "[0-9]\.[0-9]\.[0-9]"|tr -d '.')
	DBRestoreBuild=$(echo $verInfo |grep -Eo "Build [0-9]{3,5}"| grep -Eo "[0-9]{3,5}")
	
	encKeyJarLocale="$BASEDIR/WAVEBackground/WAVEEncKeyChanger$NEWVERSION.jar"
	encKeyJar=$(ls $encKeyJarLocale)
	verInfo=$(java -cp $encKeyJar com.CSL.WAVE.versionInfo.WAVEEncChangeBuildStringGen -version)	
	encKeyVer=$(echo $verInfo |grep -Eo "Version [0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,2}" |grep -Eo "[0-9]\.[0-9]\.[0-9]"|tr -d '.')
	encKeyBuild=$(echo $verInfo |grep -Eo "Build [0-9]{3,5}"| grep -Eo "[0-9]{3,5}")

	waveCLIJarLocale="$BASEDIR/WAVECLI/WAVECLI$NEWVERSION.jar"
	waveCLIJar=$(ls $waveCLIJarLocale)
	verInfo=$(java -cp $waveCLIJar com.CSL.WAVE.versionInfo.CLIBuildStringGen -version)
	waveCLIVer=$( echo $verInfo |grep -Eo "Version [0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,2}" |grep -Eo "[0-9]\.[0-9]\.[0-9]"|tr -d '.')
	waveCLIBuild=$(echo $verInfo |grep -Eo "Build [0-9]{3,5}"| grep -Eo "[0-9]{3,5}")

	passResetterJarLocale="$BASEDIR/WAVEBackground/PasswordReseter.jar"
	passResetterJar=$(ls $passResetterJarLocale)
	verInfo=$(java -cp $passResetterJar com.CSL.WAVE.versionInfo.PassReseterBuildStringGen -version)
	passResetterVer=$(echo $verInfo |grep -Eo "Version [0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,2}" |grep -Eo "[0-9]\.[0-9]\.[0-9]"|tr -d '.')
	passResetterBuild=$(echo $verInfo |grep -Eo "Build [0-9]{3,5}"| grep -Eo "[0-9]{3,5}")
	
	#WaveDB not checked for update
	#waveDBVer=$(grep -E "WAVEDB_Version" $BACKUPDIR/WAVEDBDump.sql |grep -Eo "[0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,2}" |tr -d '.')
	
	##Jar was added post GA, so need to handle the possibility of Jar not existing on WaveServer
	if [ ! -e $BASEDIR/WAVEBackground/WAVEDataCapture$NEWVERSION.jar ];then
		dataCaptureJar=$BASEDIR/WAVEBackground/WAVEDataCapture$NEWVERSION.jar
	else
		dataCaptureJar=$(ls $BASEDIR/WAVEBackground/WAVEDataCapture$NEWVERSION.jar)
		verInfo=$(java -cp $dataCaptureJar com.CSL.WAVE.versionInfo.DataCaptureBuildStringGen -version)
		dataCaptureVer=$(echo $verInfo |grep -Eo "Version [0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,2}" |grep -Eo "[0-9]\.[0-9]\.[0-9]"|tr -d '.')
		dataCaptureBuild=$(echo $verInfo |grep -Eo "Build [0-9]{1,5}"| grep -Eo "[0-9]{1,5}")		
	fi	
	#Script was added post GA, so need to handle possiblility of script not existing on waveserver
	if [ ! -e $BASEDIR/WAVEBackground/WAVEDataCapture ];then
		dataCaptureScriptVer="0"
	else	
		dataCaptureScriptVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $BASEDIR/WAVEBackground/WAVEDataCapture |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	fi
	
	webScriptVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $BASEDIR/GUI/scripts.js |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')	
	waveJnlpVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $BASEDIR/GUI/WAVE.jnlp |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	waveBackgroundServicesVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $BASEDIR/WAVEBackground/WAVEBackgroundServices |grep -Eo "[0-9]\.[0-9]{2}" |tr -d '.')
	testApiJnlpVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $BASEDIR/GUI/TestAPI.jnlp |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	
	indexVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $BASEDIR/GUI/index.html |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	styleVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $BASEDIR/GUI/style.css |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	execNotificationVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $BASEDIR/GUI/CLI/execNotification.cgi |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	changeWaveSrvIpVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $BASEDIR/install/changeWAVESRVIP.sh |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	versionScriptVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $BASEDIR/install/IBM-Wave-Ver.scr |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	defaultServerVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $BASEDIR/install/default-server.conf |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	httpdVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $BASEDIR/install/httpd.conf |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	httpdRh5Ver=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $BASEDIR/install/httpd.conf.rhel5 |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	httpdRh6Ver=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $BASEDIR/install/httpd.conf.rhel6 |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	loadClcVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $BASEDIR/install/loadCLC.scr |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	logRotateVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $BASEDIR/install/logrotate.conf |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	myCnfVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $BASEDIR/install/my.cnf |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	myCnfRhVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $BASEDIR/install/my.cnf.rh |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	waveCronVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $BASEDIR/install/WAVE.cron |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	internalExecutorVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $BASEDIR/scripts/WAVEInternal.WAVE_Executor |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	dbRestoreScriptVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $BASEDIR/WAVEBackground/WAVEDBRestorer |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	encryptChangerVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $BASEDIR/WAVEBackground/WAVEEncryptChanger |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	passResetterScriptVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $BASEDIR/WAVEBackground/WAVEPasswordReseter |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	networkUpdateVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $BASEDIR/WAVECLI/networkUpdate.scr |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	packWaveCliVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $BASEDIR/WAVECLI/packWAVECLI |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	cliBatVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $BASEDIR/WAVECLI/wavecli.bat |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	cliScrVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $BASEDIR/WAVECLI/wavecli.scr |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	sm191Ver=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $BASEDIR/install/smVer |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')

	#logging
	#echo "Installed Build Levels" >>logFile
	#echo "waveBuild:$waveBuild" >>logFile;echo "commonBuild:$commonBuild" >>logFile;echo "BackgroundBuild:$backgroundBuild">>logFile;echo "testAPIBuild:$testApiBuild">>logFile; echo "DBRestoreBuild:$DBRestoreBuild">>logFile
	#echo "encKeyBuild:$encKeyBuild">>logFile;echo "waveCLIBuild:$waveCLIBuild">>logFile; echo "passResetterBuild:$passResetterBuild">>logFile;
	
}	

#Sets Versions found in update package
function setUpdateVersions(){
	updateWaveJar=$(ls $runDir/GUI/appl/WAVE$NEWVERSION.jar)
	verInfo=$(java -cp $updateWaveJar com.CSL.WAVE.versionInfo.GUIBuildStringGen -version)
	updateWaveVer=$(echo $verInfo |grep -Eo "Version [0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,2}" |grep -Eo "[0-9]\.[0-9]\.[0-9]"|tr -d '.')
	updateWaveBuild=$(echo $verInfo|grep -Eo "Build [0-9]{3,5}"|grep -Eo "[0-9]{3,5}")	
	
	updateCommonJar=$(ls $runDir/GUI/Common/WAVECommon$NEWVERSION.jar)
	verInfo=$(java -cp $updateCommonJar com.CSL.WAVE.versionInfo.CommonsBuildStringGen -version)
	updateCommonVer=$(echo $verInfo |grep -Eo "Version [0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,2}" |grep -Eo "[0-9]\.[0-9]\.[0-9]"|tr -d '.')	
	updateCommonBuild=$(echo $verInfo |grep -Eo "Build [0-9]{3,5}" |grep -Eo "[0-9]{3,5}")
	
	updateBackgroundJar=$(ls $runDir/WAVEBackground/WAVEBackground$NEWVERSION.jar)
	verInfo=$(java -cp $updateBackgroundJar com.CSL.WAVE.versionInfo.DBUpdateBuildStringGen -version)
	updateBackgroundVer=$(echo $verInfo |grep -Eo "Version [0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,2}" |grep -Eo "[0-9]\.[0-9]\.[0-9]"|tr -d '.')
	updateBackgroundBuild=$(echo $verInfo |grep -Eo "Build [0-9]{3,5}"| grep -Eo "[0-9]{3,5}")
	
	updateTestApiJar=$(ls $runDir/GUI/TestAPI/TestAppl.jar)
	verInfo=$(java -cp $updateTestApiJar com.CSL.WAVE.versionInfo.TestAPIBuildStringGen -version)	
	updateTestApiVer=$(echo $verInfo |grep -Eo "Version [0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,2}" |grep -Eo "[0-9]\.[0-9]\.[0-9]"|tr -d '.')
	updateTestApiBuild=$(echo $verInfo |grep -Eo "Build [0-9]{3,5}"| grep -Eo "[0-9]{3,5}")	

	updateDBRestoreJar=$(ls $runDir/WAVEBackground/WAVEDBRestorer$NEWVERSION.jar)	
	verInfo=$(java -cp $updateDBRestoreJar com.CSL.WAVE.versionInfo.WAVEDBRestoreBuildStringGen -version)
	updateDBRestoreVer=$(echo $verInfo |grep -Eo "Version [0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,2}" |grep -Eo "[0-9]\.[0-9]\.[0-9]"|tr -d '.')
	updateDBRestoreBuild=$(echo $verInfo |grep -Eo "Build [0-9]{3,5}"| grep -Eo "[0-9]{3,5}")
	
	updateEncKeyJar=$(ls $runDir/WAVEBackground/WAVEEncKeyChanger$NEWVERSION.jar)
	verInfo=$(java -cp $updateEncKeyJar com.CSL.WAVE.versionInfo.WAVEEncChangeBuildStringGen -version)	
	updateEncKeyVer=$(echo $verInfo |grep -Eo "Version [0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,2}" |grep -Eo "[0-9]\.[0-9]\.[0-9]"|tr -d '.')
	updateEncKeyBuild=$(echo $verInfo |grep -Eo "Build [0-9]{3,5}"| grep -Eo "[0-9]{3,5}")

	updateWaveCLIJar=$(ls $runDir/WAVECLI/WAVECLI$NEWVERSION.jar)
	verInfo=$(java -cp $updateWaveCLIJar com.CSL.WAVE.versionInfo.CLIBuildStringGen -version)	
	updateWaveCLIVer=$(echo $verInfo |grep -Eo "Version [0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,2}" |grep -Eo "[0-9]\.[0-9]\.[0-9]"|tr -d '.')
	updateWaveCLIBuild=$(echo $verInfo |grep -Eo "Build [0-9]{3,5}"| grep -Eo "[0-9]{3,5}")

	updatePassResetterJar=$(ls $runDir/WAVEBackground/PasswordReseter.jar)
	verInfo=$(java -cp $updatePassResetterJar com.CSL.WAVE.versionInfo.PassReseterBuildStringGen -version)	
	updatePassResetterVer=$(echo $verInfo |grep -Eo "Version [0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,2}" |grep -Eo "[0-9]\.[0-9]\.[0-9]"|tr -d '.')
	updatePassResetterBuild=$(echo $verInfo |grep -Eo "Build [0-9]{3,5}"| grep -Eo "[0-9]{3,5}")

	updateDataCaptureJar=$(ls $runDir/WAVEBackground/WAVEDataCapture$NEWVERSION.jar)
	verInfo=$(java -cp $updateDataCaptureJar com.CSL.WAVE.versionInfo.DataCaptureBuildStringGen -version)
	updateDataCaptureVer=$(echo $verInfo |grep -Eo "Version [0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,2}" |grep -Eo "[0-9]\.[0-9]\.[0-9]"|tr -d '.')
	updateDataCaptureBuild=$(echo $verInfo |grep -Eo "Build [0-9]{1,5}"| grep -Eo "[0-9]{1,5}")

	#Greps out WAVEDB_Version from WAVEDBDump.sql in backup dir(created when backing files up) to determine db version
	#updateWaveDBVer=$(grep -E "WAVEDB_Version" $runDir/install/WAVEDBDump.sql |grep -Eo "[0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,2}" |tr -d '.')

	updateDataCaptureScriptVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $runDir/WAVEBackground/WAVEDataCapture |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	updateWebScriptVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $runDir/GUI/scripts.js |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	updateWaveJnlpVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $runDir/GUI/WAVE.jnlp |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	updateWaveBackgroundServicesVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $runDir/WAVEBackground/WAVEBackgroundServices |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	updateTestApiJnlpVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $runDir/GUI/TestAPI.jnlp |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	
	updateIndexVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $runDir/GUI/index.html |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	updateStyleVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $runDir/GUI/style.css |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	updateExecNotificationVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $runDir/GUI/CLI/execNotification.cgi |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	updateChangeWaveSrvIpVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $runDir/install/changeWAVESRVIP.sh |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	updateVersionScriptVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $runDir/install/IBM-Wave-Ver.scr |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	updateDefaultServerVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $runDir/install/default-server.conf |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	updateHttpdVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $runDir/install/httpd.conf |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	updateHttpdRh5Ver=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $runDir/install/httpd.conf.rhel5 |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	updateHttpdRh6Ver=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $runDir/install/httpd.conf.rhel6 |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	updateLoadClcVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $runDir/install/loadCLC.scr |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	updateLogRotateVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $runDir/install/logrotate.conf |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	updateMyCnfVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $runDir/install/my.cnf |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	updateMyCnfRhVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $runDir/install/my.cnf.rh |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	updateWaveCronVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $runDir/install/WAVE.cron |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	updateInternalExecutorVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $runDir/scripts/WAVEInternal.WAVE_Executor |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	updateDbRestoreScriptVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $runDir/WAVEBackground/WAVEDBRestorer |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	updateEncryptChangerVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $runDir/WAVEBackground/WAVEEncryptChanger |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	updatePassResetterScriptVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $runDir/WAVEBackground/WAVEPasswordReseter |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	updateNetworkUpdateVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $runDir/WAVECLI/networkUpdate.scr |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	updatePackWaveCliVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $runDir/WAVECLI/packWAVECLI |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	updateCliBatVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $runDir/WAVECLI/wavecli.bat |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	updateCliScrVer=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $runDir/WAVECLI/wavecli.scr |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')
	updateSm191Ver=$(grep -Eo "Version:[0-9]{1,2}\.[0-9]{2,3}" $runDir/install/smVer |grep -Eo "[0-9]{1,2}\.[0-9]{2,3}" |tr -d '.')

	#logging
	#echo "Updater Build Levels" >>logFile
	#echo "updateWaveBuild:$updateWaveBuild" >>logFile;echo "updateCommonBuild:$updateCommonBuild" >>logFile;echo "updateBackgroundBuild:$updateBackgroundBuild>>logFile";echo "updateTestAPIBuild:$updateTestApiBuild">>logFile; echo "updateDBRestoreBuild:$DBRestoreBuild">>logFile
	#echo "updateEncKeyBuild:$updateEncKeyBuild">>logFile;echo "updateWaveCLIBuild:$updateWaveCLIBuild">>logFile; echo "updatePassResetterBuild:$updatePassResetterBuild">>logFile;
}

#compares currently installed build levels to the build levels in upgrade pack
function compareVersions() {
	
	if [ -z $waveBuild ]; then
		updateWave=true	
	elif [ $waveBuild -lt $updateWaveBuild ]; then
		updateWave=true
	fi
	
	if [ -z $commonBuild ]; then
		updateCommon=true
	elif  [ $commonBuild -lt $updateCommonBuild ]; then
		updateCommon=true
	fi
	
	if [ -z $backgroundBuild ]; then
		updateBackground=true
	elif [ $backgroundBuild -lt $updateBackgroundBuild ]; then
		updateBackground=true
	fi
	
	if [ -z $DBRestoreBuild ]; then
		updateDBRestorer=true
	elif [ $DBRestoreBuild -lt $updateDBRestoreBuild ]; then
		updateDBRestorer=true	
	fi

	if [ -z $testApiBuild ]; then
		updateTestAPI=true
	elif [ $testApiBuild -lt $updateTestApiBuild ]; then
		updateTestAPI=true
	fi
	
	if [ -z $encKeyBuild ]; then
		updateEncKey=true	
	elif [ $encKeyBuild -lt $updateEncKeyBuild ]; then
		updateEncKey=true		
	fi
	
	if [ -z $waveCLIBuild ]; then
		updateCLI=true
	elif [ $waveCLIBuild -lt $updateWaveCLIBuild ]; then
		updateCLI=true
	fi

	if [ -z $webScriptVer ]; then
		updateWebScript=true
	elif [ $webScriptVer -lt $updateWebScriptVer ]; then
		updateWebScript=true
	fi
	
	if [ -z $waveJnlpVer ]; then
		updateWaveJnlp=true
	elif [ $waveJnlpVer -lt $updateWaveJnlpVer ]; then
		updateWaveJnlp=true	
	fi

	if [ -z $waveBackgroundServicesVer ] || [ $waveBackgroundServicesVer -lt $updateWaveBackgroundServicesVer ]; then
		updateBackgroundServices=true
	fi

	if [ -z $testApiJnlpVer ] || [ $testApiJnlpVer -lt $updateTestApiJnlpVer ]; then
		updateTestJnlp=true
	fi
	
	if [ -z $passResetterBuild ]; then
		updatePassResetter=true
	elif [ $passResetterBuild -lt $updatePassResetterBuild ]; then
		updatePassResetter=true
	fi
	
	if [ -z $indexVer ];then
		updateIndex=true
	elif [ $indexVer -lt $updateIndexVer ];then
		updateIndex=true
	fi
	
	if [ -z $styleVer ];then
		updateStyle=true
	elif [ $styleVer -lt $updateStyleVer ];then
		updateStyle=true
	fi
	
	if [ -z $execNotificationVer ];then
		updateExecNotification=true
	elif [ $execNotificationVer -lt $updateExecNotificationVer ];then
		updateExecNotification=true
	fi
			
	if [ -z $changeWaveSrvIpVer ];then
		updateWaveSrvIP=true
	elif [ $changeWaveSrvIpVer -lt $updateChangeWaveSrvIpVer ];then
		updateWaveSrvIP=true
	fi

	if [ -z $versionScriptVer ];then
		updateVersionScript=true
	elif [ $versionScriptVer -lt $updateVersionScriptVer ];then
		updateVersionScript=true
	fi

	if [ -z $defaultServerVer ];then
		updateServerConf=true
	elif [ $defaultServerVer -lt $updateDefaultServerVer ];then
		updateServerConf=true
	fi

	if [ -z $httpdVer ];then
		updateHttpd=true
	elif [ $httpdVer -lt $updateHttpdVer ];then
		updateHttpd=true
	fi
	
	if [ -z $httpdRh5Ver ];then
		updateHttpdRh5=true
	elif [ $httpdRh5Ver -lt $updateHttpdRh5Ver ];then
		updateHttpdRh5=true
	fi
	
	if [ -z $httpdRh6Ver ];then
		updateHttpdRh6=true
	elif [ $httpdRh6Ver -lt $updateHttpdRh6Ver ];then
		updateHttpdRh6=true
	fi

	if [ -z $loadClcVer ];then
		updateLoadClc=true	
	elif [ $loadClcVer -lt $updateLoadClcVer ];then
		updateLoadClc=true	
	fi
	
	if [ -z $logRotateVer ];then
		updateLogRotate=true
	elif [ $logRotateVer -lt $updateLogRotateVer ];then
		updateLogRotate=true
	fi

	if [ -z $myCnfVer ];then
		updateMyCnf=true
	elif  [ $myCnfVer -lt $updateMyCnfVer ];then
		updateMyCnf=true
	fi

	if [ -z $myCnfRhVer ];then
		updateMyCnfRh=true
	elif [ $myCnfRhVer -lt $updateMyCnfRhVer ];then
		updateMyCnfRh=true
	fi
	
	if [ -z $waveCronVer ];then
		updateWaveCron=true
	elif [ $waveCronVer -lt $updateWaveCronVer ];then
		updateWaveCron=true
	fi
	
	if [ -z $internalExecutorVer ];then
		updateInternalExecutor=true
	elif [ $internalExecutorVer -lt $updateInternalExecutorVer ];then
		updateInternalExecutor=true
	fi

	if [ -z $dbRestoreScriptVer ];then
		updateDBRestoreScript=true
	elif [ $dbRestoreScriptVer -lt $updateDbRestoreScriptVer ];then
		updateDBRestoreScript=true
	fi

	if [ -z $encryptChangerVer ];then
		updateEncryptChanger=true
	elif [ $encryptChangerVer -lt $updateEncryptChangerVer ];then
		updateEncryptChanger=true
	fi
	
	if [ -z $passResetterScriptVer ];then
		updatePassResetterScript=true	
	elif [ $passResetterScriptVer -lt $updatePassResetterScriptVer ];then
		updatePassResetterScript=true		
	fi
	
	if [ -z $networkUpdateVer ];then
		updateNetworkUpdate=true
	elif [ $networkUpdateVer -lt $updateNetworkUpdateVer ];then
		updateNetworkUpdate=true
	fi
	
	if [ -z $packWaveCliVer ];then
		updatePackWaveCLI=true
	elif [ $packWaveCliVer -lt $updatePackWaveCliVer ];then
		updatePackWaveCLI=true
	fi
	
	if [ -z $cliBatVer ];then
		updateCLIBat=true
	elif [ $cliBatVer -lt $updateCliBatVer ];then
		updateCLIBat=true
	fi
	
	if [ -z $cliScrVer ];then
		updateCLIScr=true
	elif [ $cliScrVer -lt $updateCliScrVer ];then
		updateCLIScr=true
	fi
	
	if [ -z $sm191Ver ];then
		updateSM=true
	elif [ $sm191Ver -lt $updateSm191Ver ];then
		updateSM=true
	fi
	
	if [ -z $dataCaptureBuild ];then
		updateDataCapture=true
	elif [ $dataCaptureBuild -lt $updateDataCaptureBuild ];then
		updateDataCapture=true
	fi
	
	if [ -z $dataCaptureScriptVer ];then
		updateDataCaptureScript=true
	elif [ $dataCaptureScriptVer -lt $updateDataCaptureScriptVer ];then
		updateDataCaptureScript=true
	fi	

	updateList="$updateSM $updateWave  $updateCommon  $updateBackground  $updateDBRestorer  $updateEncKey  $updateCLI  $updateWebScript  $updateWaveJnlp  $updateBackgroundServices  $updateTestJnlp  $updatePassResetter  $updateTestAPI  $updatePassResetterScript  $updateInternalExecutor  $updateCLIScr  $updateCLIBat  $updateNetworkUpdate  $updateEncryptChanger  $updateDBRestoreScript  $updateWaveCron $updateMyCnfRh  $updateMyCnf  $updateLogRotate  $updateLoadClc  $updateHttpdRh6  $updateHttpdRh5  $updateHttpd  $ServerConf  $updateVersionScript  $updateWaveSrvIP  $updateExecNotification  $updateStyle  $updateIndex $updateDataCapture $updateDataCaptureScript"
		
	for component in $updateList; do
		#echo $component	
		if $component ; then
			update=true	
		fi
	done
}

#Function to set the current OS the server is installed on, updating requires moving files to different locations per distro
function getOS() {
	if [ -f /etc/SuSE-release ]; then
    	distro="suse"
		#Check to see if a secod release file for rhel exists, if it does installer will cancel
		if [ -f /etc/redhat-release ]; then
			echo "Two distro release files detected in /etc. Could not determine OS"
			exit 1
		fi
			
    	level=$(cat /etc/SuSE-release | grep "VERSION = [0-9]\+" | grep -o "[0-9]\+")
    	patchLevel=$( cat /etc/SuSE-release | grep "PATCHLEVEL = [0-9]\+" | grep -o "[0-9]\+")
     
     elif [ -f /etc/redhat-release ]; then
		if [ -f /etc/SuSE-release ]; then
			echo "Two distro release files detected in /etc. Could not determine OS"
			exit 1
		fi
	
    		a=`grep -i 'red.*hat.*enterprise.*linux' /etc/redhat-release`
    	if test $? = 0; then
        	 	distro=rhel
    	fi
        fullVersion=$( cat /etc/redhat-release  |grep -o "[0-9]\+.[0-9]\+")
        level=$(echo "$fullVersion" |cut -f1 -d ".")
        patchLevel=$(echo "$fullVersion" |cut -f2 -d ".")
        
	else 
		echo "Unsupported Operating System found, exiting.."
		exit 1
fi	
	echo "Detected $distro-$level.$patchLevel"
	echo "Detected $distro-$level.$patchLevel" >>logFile
}

#Copies Updated jars and files to the installed locations
function update(){
	echo "Updating files..."
	if $updateWave ; then
		cp --preserve=timestamps -f $updateWaveJar "$waveJarLocale"
		echo "Updated Wave Jar"
	fi
	
	if $updateCommon ;then
		cp --preserve=timestamps -f $updateCommonJar $commonJarLocale
  		cp --preserve=timestamps -f $updateCommonJar $BASEDIR/WAVECLI/CGIScript/
		echo "Updated Common Jar"
	fi

	if $updateBackground ;then
		cp --preserve=timestamps -f $updateBackgroundJar $backgroundJarLocale
		echo "Updated Background Jar"
	fi

	if $updatePassResetter ;then
		cp --preserve=timestamps -f $updatePassResetterJar $passResetterJarLocale
		echo "Updated PassResetter Jar"	
	fi
	
	if $updateDBRestorer ;then
		cp --preserve=timestamps -f $updateDBRestoreJar $DBRestoreJarLocale
		echo "Updated Wave DB Restore Jar"
	fi

	if $updateEncKey ;then
		cp --preserve=timestamps -f $updateEncKeyJar $encKeyJarLocale
		echo "Updated Wave Encyption Key Jar"
	fi

	if $updateCLI ;then
		cp --preserve=timestamps -f $updateWaveCLIJar $waveCLIJarLocale
		cp --preserve=timestamps -f $updateWaveCLIJar $BASEDIR/WAVECLI/CGIScript/
		echo "Updated CLI Jar"
	fi
	
	if $updateWebScript ;then		
		cp --preserve=timestamps -f $runDir/GUI/scripts.js $BASEDIR/GUI/
		echo "Updated webScript Version"	
	fi
	
	if $updateWaveJnlp ;then
		cp --preserve=timestamps -f $runDir/GUI/WAVE.jnlp $BASEDIR/GUI/
		sed -i s/@@@SERVER_IP@@@/$IP_ADDRESS/g $BASEDIR/GUI/WAVE.jnlp
		echo "Updated Wave.jnlp"			
	fi
	
	if $updateBackgroundServices ; then
		cp --preserve=timestamps -f $runDir/WAVEBackground/WAVEBackgroundServices $BASEDIR/WAVEBackground/
		cp --preserve=timestamps -f $runDir/WAVEBackground/WAVEBackgroundServices /etc/init.d/
		echo "Updated Background Services"
	fi

	if $updateTestJnlp ; then
		cp --preserve=timestamps -f $runDir/GUI/TestAPI.jnlp $BASEDIR/GUI/
		echo "Updated TestAPIJnlp"	
	fi
	
	if $updateTestAPI ; then
		cp --preserve=timestamps -f $updateTestApiJar $testApiJar
		echo "Updated TestAPI Jar"	
	fi

	if $updateIndex ;then
		cp --preserve=timestamps -f $runDir/GUI/index.html $BASEDIR/GUI/	
		echo "Updated index.html"	
	fi

	if $updateStyle ;then
		cp --preserve=timestamps -f $runDir/GUI/style.css $BASEDIR/GUI/
		echo "Updated style.css"
	fi

	if $updateExecNotification ;then
		cp --preserve=timestamps -f $runDir/GUI/CLI/execNotification.cgi $BASEDIR/GUI/CLI/	
		echo "Updated execNotification"
	fi

	if $updateWaveSrvIP ;then
		cp --preserve=timestamps -f $runDir/install/changeWAVESRVIP.sh $BASEDIR/install/
		echo "Updated Wavesrv IP changer"
	fi

	if $updateVersionScript ;then
		
		if [ -e $BASEDIR/install/CSL-WAVE-Ver.scr ];then
			mv CSL-WAVE-Ver.scr IBM-Wave-Ver.scr
		fi
		cp --preserve=timestamps -f $runDir/install/IBM-Wave-Ver.scr $BASEDIR/install/	
		echo "Updated version script"
	fi

	if $updateServerConf ;then
		cp --preserve=timestamps -f $runDir/install/default-server.conf $BASEDIR/install
		if [ "$distro" == "suse" ];then
			cp -f $runDir/install/default-server.conf /etc/apache2		
			echo "moving default-server.conf to /etc/apache2"
			echo "Updated default-server-conf (suse)"		
		fi		
	fi	
	
	if $updateHttpd ;then
		cp --preserve=timestamps -f $runDir/install/httpd.conf $BASEDIR/install
		echo "Updated httpd.conf"
	fi

	if $updateHttpdRh5 ;then
		cp --preserve=timestamps -f $runDir/install/httpd.conf.rhel5 $BASEDIR/install/
		if [ "$distro" == "rhel" ];then
			if [ "$level" == "5" ];then
				cp --preserve=timestamps -f $runDir/install/httpd.conf.rhel5 /etc/httpd/conf/httpd.conf	
				echo "Updated httpd.conf (redhat5)"		
			fi 		
		fi
			
	fi

	if $updateHttpdRh6; then
		cp --preserve=timestamps -f $runDir/install/httpd.conf.rhel6 $BASEDIR/install/
		if [ "$distro" == "rhel" ];then
			if [ "level" == "6" ];then
				cp --preserve=timestamps -f $runDir/install/httpd.conf.rhel6 /etc/httpd/conf/httpd.conf	
				echo "Updated httpd.conf (redhat6)"		
			fi		
		fi			
	fi

	if $updateLoadClc; then
		cp --preserve=timestamps -f $runDir/install/loadCLC.scr $BASEDIR/install/
		echo "Updated loadCLC"	
	fi

	if $updateLogRotate; then
		cp --preserve=timestamps -f $runDir/install/logrotate.conf $BASEDIR/install/	
		echo "Updated logRotate"	
	fi
	
	if $updateMyCnf; then
		cp --preserve=timestamps -f $runDir/install/my.cnf $BASEDIR/install/		
		if [ "$distro" == "suse" ];then
			cp --preserve=timestamps -f $runDir/install/my.cnf /etc/
			echo "Updated my.cnf (suse)"		
		fi
	fi
	
	if $updateMyCnfRh; then
		cp --preserve=timestamps -f $runDir/install/my.cnf.rh $BASEDIR/install/
		if [ "$distro" == "rhel" ];then
			cp --preserve=timestamps -f $runDir/install/my.cnf.rh /etc/my.cnf
			echo "Updated my.cnf (redhat)"		
		fi
			
	fi

	if $updateWaveCron; then
		cp --preserve=timestamps -f $runDir/install/WAVE.cron $BASEDIR/install/
		cp --preserve=timestamps -f $runDir/install/WAVE.cron /etc/cron.hourly/
		echo "Updated WAVE.cron"	
	fi

	if $updateInternalExecutor; then
		cp --preserve=timestamps -f $runDir/scripts/WAVEInternal.WAVE_Executor $BASEDIR/scripts/
		echo "Updated Wave Internal Executor"
	fi

	if $updateDBRestoreScript; then
		cp --preserve=timestamps -f $runDir/WAVEBackground/WAVEDBRestorer $BASEDIR/WAVEBackground/
		echo "Updated DB Restore Script"	
	fi 

	if $updateEncryptChanger; then
		cp --preserve=timestamps -f $runDir/WAVEBackground/WAVEEncryptChanger $BASEDIR/WAVEBackground/	
		echo "Updated Encrypt Changer"	
	fi

	if $updatePassResetterScript; then
		cp --preserve=timestamps -f $runDir/WAVEBackground/WAVEPasswordReseter $BASEDIR/WAVEBackground/
		echo "Updated Pass Resetter"	
	fi

	if $updateNetworkUpdate; then
		cp --preserve=timestamps -f $runDir/WAVECLI/networkUpdate.scr $BASEDIR/WAVECLI/
		echo "Updated networkUpdate script"
	fi

	if $updatePackWaveCLI; then
		cp --preserve=timestamps -f $runDir/WAVECLI/packWAVECLI $BASEDIR/WAVECLI/
		echo "Updated packWAVECLI"	
	fi
	
	if $updateCLIBat; then
		cp --preserve=timestamps -f $runDir/WAVECLI/wavecli.bat $BASEDIR/WAVECLI/	
		echo "Updated waveCLI.bat"
	fi

	if $updateCLIScr; then
		cp --preserve=timestamps -f $runDir/WAVECLI/wavecli.scr $BASEDIR/WAVECLI/
		echo "Updated waveCLI.scr"	
	fi
	if $updateSM; then
		cp --preserve=timestamps -f $runDir/install/WAVECLC/* $BASEDIR/install/WAVECLC/
		cp --preserve=timestamps -f $runDir/install/WAVEdisk/* $BASEDIR/install/WAVEdisk/
		cp --preserve=timestamps -f $runDir/install/smVer	$BASEDIR/install/
		echo "Updated SM REXX files"
	fi
	
	if $updateDataCapture;then
		cp --preserve=timestamps -f $updateDataCaptureJar $BASEDIR/WAVEBackground/
		chown waveuser $BASEDIR/WAVEBackground/WAVEDataCapture$NEWVERSION.jar
		chmod 755 $BASEDIR/WAVEBackground/WAVEDataCapture$NEWVERSION.jar		
		echo "Updated DataCapture Jar"	
	fi
	
	if $updateDataCaptureScript;then
		cp --preserve=timestamps -f $runDir/WAVEBackground/WAVEDataCapture $BASEDIR/WAVEBackground/
		chown waveuser $BASEDIR/WAVEBackground/WAVEDataCapture
		echo "Updated DataCapture Script"	
	fi

}

#service machine updates using the javaupgrader
function runUpdateJar() {
	if [ "$2" == "-SMUpgrade" ];then
		echo "Checking for knowledgebase updates, and re-popuating service machines..."
	else
		echo "Checking for knowledgebase updates"
	fi
	cp="$waveJar:$commonJar:$backgroundJar:$BASEDIR/GUI/Common/jcommon-serializer-0.2.0.jar:$BASEDIR/GUI/Common/commons-collections-3.2.jar:$BASEDIR/GUI/Common/jdom.jar:$BASEDIR/WAVEBackground/commons-dbcp-1.2.2.jar:$BASEDIR/GUI/Common/jsch-0.1.42.jar:$BASEDIR/GUI/Common/commons-pool-1.4.jar:$runDir/WAVE-SP-Upgrader.jar:$BASEDIR/GUI/Common/jcommon-1.0.12.jar:$BASEDIR/WAVEBackground/mariadb-java-client-1.1.1.jar:$BASEDIR/GUI/Common/log4j-1.2.16.jar:$BASEDIR/WAVEBackground/commons-net-2.2.jar"
	java -classpath $cp com.CSL.WAVE.upgrader.main.RunUpgrade $1 $2
}
#Restart BTS
function restartBTS (){
	echo "Restarting Background Services..."
	/etc/init.d/WAVEBackgroundServices start
}
#Restart services
function restartServices (){
	errStatus=0
	
	echo "Restarting services"
	if [ "$distro" == "suse" ];then
		echo "Restarting mysql..."
		if ! /etc/init.d/mysql start;then
			errStatus=8
		fi
	
		echo "Restarting apache2..."
		if ! /etc/init.d/apache2 start;then
			errStatus=8
		fi
	
	elif [ "$distro" == "rhel" ];then
		echo "Restarting mysql..."
		if ! /etc/init.d/mysqld start;then
			errStatus=8
		fi
		
		echo "Restarting httpd"
		if ! /etc/init.d/httpd start;then
			errStatus=8
		fi
	fi
	
	return $errStatus
}
#Creates backup directories and copies current files (and sql dump to there)
function backup() {
	echo "Backing up old version files..."
	rm -rf $BACKUP_DIR
	mkdir $BACKUP_DIR
	
	#backup Directory to be used for knowledgebase by Jar
	mkdir $BACKUP_DIR/knowledgebase
	
	for dir in $(ls $BASEDIR | grep -v '^backup-');do
		cp -pr $BASEDIR/$dir $BACKUP_DIR
	done
	
}

function compressBackup() {
	echo "Compressing $BACKUP_DIR..."	
	tar -czf $BACKUP_DIR.tar.gz -C $BASEDIR $BACKUP_DIR_NAME	
	rm -rf $BACKUP_DIR
}

#will set the $ROLLBACK_DIR variable to the latest backup of the last level
#also sets $ROLLBACK_VER_INFO, $ROLLBACK_VER, and $ROLLBACK_BUILD to appropriate build info
function setRollbackDir() {
	ROLLBACK_DIR=
	ROLLBACK_FIX_PACK=0
	ROLLBACK_VER=0
	ROLLBACK_BUILD=0
	
	setCurrentVersions
	
	#go through all of the backup archives in the installation directory
	for backupArchive in $(ls -r $BASEDIR | grep '^backup-.*\.tar\.gz$'); do
		backupDir=$BASEDIR/$(echo $backupArchive | sed -r 's/\.[[:alnum:]]+\.[[:alnum:]]+$//')
		
		
		#invalid backup since we can't untar backup archive or can't find WAVEBackground jar
		if ! $(tar -xzf $backupDir.tar.gz -C /usr/wave && \
				ls $backupDir/WAVEBackground/ | grep '^WAVEBackground.*\.jar$' > /dev/null); then 
			echo "$backupDir is not a valid backup."
			rm -rf $backupDir 2> /dev/null
			continue
		fi
		
		backupJar="$backupDir/WAVEBackground/$(ls $backupDir/WAVEBackground/ | grep '^WAVEBackground.*\.jar$' | tail -n 1)"
		backupVerInfo=$(java -cp $backupJar com.CSL.WAVE.versionInfo.DBUpdateBuildStringGen -version 2> /dev/null)
		
		#invalid backup since we couldn't get the version
		if [[ $? != 0 ]];then
			echo "$backupDir is not a valid backup."
			rm -rf $backupDir
			continue
		fi
		
		#get version and build number
		backupVer=$(echo $backupVerInfo |grep -Eo "Version [0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,2}" |grep -Eo "[0-9]\.[0-9]\.[0-9]"|tr -d '.')
		backupBuild=$(echo $backupVerInfo |grep -Eo "Build [0-9]{3,5}"| grep -Eo "[0-9]{3,5}")
		
		#test to see if the build and version are valid numbers
		if ! $(expr $backupVer$backupBuild + 1 2> /dev/null > /dev/null); then
			echo "$backupDir is not a valid backup"
			rm -rf $backupDir
			continue
		fi
		
		#invalid backup since we don't support version before FixPack 3
		if  (( $backupVer$backupBuild < 110503 ));then
			echo $backupVer$backupBuild
			echo "$backupDir has a version of IBM Wave before FixPack 3." 
			echo "We do not support rollback to versions before FixPack 3."
			echo "Please contact your IBM Wave representative for more information."
			rm -rf $backupDir
			continue
		fi
		
		#invalid backup since the backup version is later or the same as the installed version
		if (( $backupVer$backupBuild >= $backgroundVer$backgroundBuild ));then
			echo "$backupDir contains a version of IBM Wave later or the same of the installed version."
			rm -rf $backupDir
			continue 
		fi
		
		#finally found a good backup!
		if	(( $backupVer$backupBuild > $ROLLBACK_VER$ROLLBACK_BUILD ));then
			
			if [[ -n $ROLLBACK_DIR ]];then
				rm -rf $ROLLBACK_DIR
			fi
			
			ROLLBACK_DIR=$backupDir
			ROLLBACK_VER=$backupVer
			ROLLBACK_BUILD=$backupBuild
			ROLLBACK_FIX_PACK=$(getFixPackNumber $ROLLBACK_BUILD)
			
		fi
	
	done
	
}

function verifyDBDump() {
	dbDumpFile=$1
	
	for table in ${tables[@]};do
		if ! $(grep -q $table $dbDumpFile);then
			return 8
		fi
	done
}

#rolls back the database, if the database backup file exists in the backup directory
function rollbackDB() {
	if $(find $ROLLBACK_DIR/knowledgebase/ -name 'backupSQLDump-*.sql' | grep -q '.'); then
		backupSQLFile=$(find $ROLLBACK_DIR/knowledgebase/ -name 'backupSQLDump-*.sql' | tail -n 1)
		
		verifyDBDump $backupSQLFile
		retStatus=$?
		
		if [[ $retStatus != 0 ]] ;then
			echo "$dbDumpFile is an invalid database backup.  Aborting..."
		else
			echo "Rolling back database using ${backupSQLFile}." 
			cd /usr/wave/WAVEBackground/
			./WAVEDBRestorer $backupSQLFile
			retStatus=$?
		
			cd - >> /dev/null
		fi
		
	else
		echo "No database backup file found."
	fi
	
	return $retStatus
	
}

function rollbackSM() {
	echo "Rolling back service machines..."
	cp="$waveJar:$commonJar:$backgroundJar:$BASEDIR/GUI/Common/jcommon-serializer-0.2.0.jar:$BASEDIR/GUI/Common/commons-collections-3.2.jar:$BASEDIR/GUI/Common/jdom.jar:$BASEDIR/WAVEBackground/commons-dbcp-1.2.2.jar:$BASEDIR/GUI/Common/jsch-0.1.42.jar:$BASEDIR/GUI/Common/commons-pool-1.4.jar:$runDir/WAVE-SP-Upgrader.jar:$BASEDIR/GUI/Common/jcommon-1.0.12.jar:$BASEDIR/WAVEBackground/mariadb-java-client-1.1.1.jar:$BASEDIR/GUI/Common/log4j-1.2.16.jar:$BASEDIR/WAVEBackground/commons-net-2.2.jar"
	java -classpath $cp com.CSL.WAVE.upgrader.main.RunUpgrade -SMUpgrade
	
	return $?
}


function rollback() {
	if ! restartServices;then
		echo "Error starting services."
		return 8
	fi
	
	setRollbackDir
	
	if [[ -z $ROLLBACK_DIR ]]; then
		echo "No valid backup found.  Rollback aborted."
		return 5
	fi
	
	echo "You will rollback from IBM Wave Version 1.1.0 FixPack $backgroundFixPack to IBM Wave 1.1.0 FixPack $ROLLBACK_FIX_PACK."
	echo "The backup archive $ROLLBACK_DIR.tar.gz will be used."
	echo "Continue? (y/n)"
	
	while [[ -z $userAns ]];do		
			read userAns
	done
	if ! [[ $userAns == "y"  ||  $userAns == "Y" || $userAns == "yes" || $userAns == "Yes" ]];then
		return 8
	fi	
	
	rollbackDB
	retStatus=$?
	
	if [[ $retStatus != 0 ]]; then 
		echo "Rollback of database failed.  Rollback aborted."
		return $retStatus
	fi
	
	#copy back files
	echo "Copying back old installation files..."
	for dir in $(ls $ROLLBACK_DIR | grep -v '^knowledgebase$');do
		cp -pr $ROLLBACK_DIR/$dir $BASEDIR/
	done
	cp -p  $BASEDIR/WAVEBackground/WAVEBackgroundServices /etc/init.d
	
	
	rollbackSM
	retStatus=$?
	
	if [[ $retStatus != 0 ]]; then 
		echo "Rollback of service machines failed. Rollback aborted."
		return $retStatus
	fi
		
	echo "Rollback complete!  You are now at FixPack $ROLLBACK_FIX_PACK."
	echo "***NOTE: Please be sure to have all IBM Wave users clear their Java cache before logging in!!***"
			
}

#Check that the linux user running the install is root
if [[ $EUID -ne 0 ]]; then
   echo "This script must be run as root" 
   exit 8
fi

shouldRollback=false
#parse arguments
#for var in "$@";do
#	case "$var" in 
#		"-rollback") 
#			shouldRollback=true
#			;;
#		*) 
#			echo "Usage: ./doUpdate.sh [-rollback]"
#			exit 1
#	esac
#done
getOS
echo "Stopping IBM-Wave Background Services..."
/etc/init.d/WAVEBackgroundServices stop
statusSuSE=$(/etc/init.d/WAVEBackgroundServices status|grep -o "not active")
statusRhel=$(/etc/init.d/WAVEBackgroundServices status|grep -o "not found")
statusDead=$(/etc/init.d/WAVEBackgroundServices status |grep -o "dead")


#rollback the system if user inputs flag
if $shouldRollback; then
		
	if [ "$statusSuSE" == "not active" ] || 
		[ "$statusRhel" == "not found" ] || 
		[ "$statusDead" == "dead" ];then
		rollback
		retStatus=$?
		
		if [[ -n $ROLLBACK_DIR ]];then
			rm -rf $ROLLBACK_DIR
		fi
		
		restartBTS
	else
		echo "Failed stopping WAVEBackgroundServices, exiting.."
		exit 1	
	fi
		
	exit $retStatus		
fi


if [ "$distro" == "suse" ];then
	echo "Stopping mysql..."
	/etc/init.d/mysql stop
	statusSql=$(/etc/init.d/mysql status |grep -o "unused")
	if [ -z $statusSql ];then
		echo "Error stopping mysql, exiting..."
		exit 8
	fi
	echo "stopping apache2..."
	/etc/init.d/apache2 stop
	statusApache=$(/etc/init.d/apache2 status |grep -o "unused")
	if [ -z $statusApache ];then
		echo "Error stopping apache, exiting..."
		exit 8
	fi
elif [ "$distro" == "rhel" ];then
	echo "Stopping mysql..."
	/etc/init.d/mysqld stop
	statusSql=$(/etc/init.d/mysqld status |grep -o "stopped")
	if [ -z $statusSql ];then
		echo "Error stopping mysqld, exiting..."
		exit 8	
	fi
	echo "Stopping httpd"
	/etc/init.d/httpd stop
	statusHttpd=$(/etc/init.d/httpd status |grep -o "stopped")
	if [ -z $statusHttpd ];then
		echo "Error stopping httpd, exiting..."
		exit 8	
	fi
else 
	echo "Unable to determine linux distro, exiting..."
		exit 5
fi

	
if [ "$statusSuSE" == "not active" ] || [ "$statusRhel" == "not found" ] || [ "$statusDead" == "dead" ];then
	backup
	echo "Checking levels and updates..."
	setUpdateVersions
	setCurrentVersions
	#Add class path for future Jar usage
	
	##Handle possibility of customer updating with PID level code
	if [ ! -z $waveBuild ];then
		if [ $waveBuild -eq "388" ];then
			echo "Can not update this level of IBM Wave. Please install first fixpack, then re-try"
			restartServices
			exit 5	
		fi
	fi	
	compareVersions
	if $update ;then
		update
		restartServices
		sleep 5						
	else
		echo "Nothing needed to update"
		restartServices		
		sleep 5		
		echo "No updates found"
	fi
	if $updateSM;then
		echo "There are newly added rexx files, it is recommended to populate the service machines with these files."
		runUpdateJar -DBUpgrade -SMUpgrade
		updateJarRc=$?	
	fi
	if ! $updateSM;then
		echo "Would you like to re-populate the Wave Service Machines? (y/n)"
		while [ -z $userAns ];do		
			read userAns
		done
		if [ $userAns == "y" ] || [ $userAns == "Y" ] || [ $userAns == "yes" ] || [ $userAns == "Yes" ];then
			runUpdateJar -DBUpgrade -SMUpgrade
			updateJarRc=$?
		else
			runUpdateJar -DBUpgrade
			updateJarRc=$?	
		fi	
	fi
	restartBTS
	
	compressBackup
	if [ $updateJarRc -eq 0 ];then
		echo "---------------------------------------------"
		echo "|                                           |"
		echo "|       IBM Wave Succesfully Updated!       |"
		echo "|                                           |"
		echo "---------------------------------------------"	
	elif [ $updateJarRc -eq 10 ];then
		echo "There was a problem checking or updating the IBM Wave Knowledgebase, please check the console for errors and re-run the Updater"
	elif [ $updateJarRc -eq 20 ];then
		echo "There was a problem populating IBM Wave service machines, please check the console for errors and re-run the Updater"
	elif [ $updateJarRc -eq 12 ];then
		echo "There was a problem backing up the current waveDB, please check the console for errors and re-run the Updater"	
	else
		echo "There was a problem checking or updating the IBM Wave Knowledgebase and service machines, please check the console for errors and re-run the Updater"
	fi


	


else
	echo "Failed stopping WAVEBackgroundServices, exiting.."
	exit 1

fi
